summaryrefslogtreecommitdiff
path: root/src/pulsecore/source.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pulsecore/source.h')
-rw-r--r--src/pulsecore/source.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/pulsecore/source.h b/src/pulsecore/source.h
index 91e8674b7..3a6b5c344 100644
--- a/src/pulsecore/source.h
+++ b/src/pulsecore/source.h
@@ -119,7 +119,7 @@ struct pa_source {
pa_atomic_t mixer_dirty;
/* The latency offset is inherited from the currently active port */
- int64_t latency_offset;
+ int64_t port_latency_offset;
unsigned priority;
@@ -229,8 +229,8 @@ struct pa_source {
pa_usec_t fixed_latency; /* for sources with PA_SOURCE_DYNAMIC_LATENCY this is 0 */
- /* This latency offset is a direct copy from s->latency_offset */
- int64_t latency_offset;
+ /* This latency offset is a direct copy from s->port_latency_offset */
+ int64_t port_latency_offset;
/* Delayed volume change events are queued here. The events
* are stored in expiration order. The one expiring next is in
@@ -275,7 +275,7 @@ typedef enum pa_source_message {
PA_SOURCE_MESSAGE_SET_MAX_REWIND,
PA_SOURCE_MESSAGE_SET_PORT,
PA_SOURCE_MESSAGE_UPDATE_VOLUME_AND_MUTE,
- PA_SOURCE_MESSAGE_SET_LATENCY_OFFSET,
+ PA_SOURCE_MESSAGE_SET_PORT_LATENCY_OFFSET,
PA_SOURCE_MESSAGE_MAX
} pa_source_message_t;
@@ -356,7 +356,7 @@ void pa_source_update_flags(pa_source *s, pa_source_flags_t mask, pa_source_flag
/*** May be called by everyone, from main context */
-void pa_source_set_latency_offset(pa_source *s, int64_t offset);
+void pa_source_set_port_latency_offset(pa_source *s, int64_t offset);
/* The returned value is supposed to be in the time domain of the sound card! */
pa_usec_t pa_source_get_latency(pa_source *s);